pub enum ModifierDirection {
Left,
Right,
Unknown,
}Expand description
Represents whether the modifier came from the left or right side of the keyboard, where applicable.
Variants
Left
Modifier came from the left side of the keyboard.
Right
Modifier came from the right side of the keyboard.
Unknown
Direction is unknown or not applicable.